/*
This is an Ozeki NFC Host example code.

Before starting, you need to download the MFRC522 library from the Arduino IDE top menu:
Sketch/Import library.../Add library... and type 'MFRC522' in the search.

Now you can connect a maximum of two RC522 modules to your Ozeki NFC Host and upload this code to the host.
Make sure that the RC522 modules are in safe distance from eachother to work properly.
Place your RFID chip close to one of the module's surface and
you should read the value contained on the chip from the serial port.

We demonstrated the work of this code in this youtube video:
https://www.youtube.com/watch?v=CglTExpt2k0
 */

#include <SPI.h>
#include <MFRC522.h>

#define SS_1_PIN 10
#define SS_2_PIN 9
#define RST_PIN_1 8
#define RST_PIN_2 7
 
MFRC522 reader_0(SS_1_PIN, RST_PIN_1); 
MFRC522 reader_1(SS_2_PIN, RST_PIN_2);

MFRC522::MIFARE_Key key; 

byte nuidPICC[4];

void setup() { 
  Serial.begin(115200);
  SPI.begin();
  reader_0.PCD_Init();
  reader_1.PCD_Init();
  Serial.println("Now you can scan the RFID chips.");
}

void loop() {
  NFC_0();
  NFC_1(); 
}

void NFC_0()
{
  for (byte i = 0; i < 6; i++) {
    key.keyByte[i] = 0xFF;
  } 
  if ( ! reader_0.PICC_IsNewCardPresent())  
  return;
  
  if (  !reader_0.PICC_ReadCardSerial())
  return;

  for (byte i = 0; i < 4; i++) {
      nuidPICC[i] = reader_0.uid.uidByte[i]; 
    }
    
  Serial.print(F("READER_0: "));
  printDec(reader_0.uid.uidByte, reader_0.uid.size);
  Serial.println();

  reader_0.PICC_HaltA();
  reader_0.PCD_StopCrypto1();
}

void NFC_1(){
  for (byte i = 0; i < 6; i++) {
    key.keyByte[i] = 0xFF;
  }
  
  if ( ! reader_1.PICC_IsNewCardPresent())
    return; 
   
  if ( ! reader_1.PICC_ReadCardSerial())
    return;

  for (byte i = 0; i < 4; i++) {
      nuidPICC[i] = reader_1.uid.uidByte[i];
  }
  Serial.print(F("READER_1: "));
  printDec(reader_1.uid.uidByte, reader_1.uid.size);
  Serial.println();

  reader_1.PICC_HaltA();

  reader_1.PCD_StopCrypto1(); 
}

void printDec(byte *buffer, byte bufferSize) {
  for (byte i = 0; i < bufferSize; i++) {
    Serial.print(buffer[i] < 0x10 ? " 0" : " ");
    Serial.print(buffer[i], DEC);
  }
}
